@@ -69,7 +69,7 @@ def main():
     file_path = filedialog.askopenfilename()
     os.chdir(cur_dir)
     test = np.load(file_path, allow_pickle = True)
-
+    file_window.destroy()
 
     root = Tk.Tk()
     root.geometry("300x200")
@@ -82,8 +82,6 @@ def main():
     for i,j in test["arr_0"][0].items():
         names.append(i)
 
-
-    print(names)
     listbox = Tk.Listbox(root, selectmode="multiple")
 
     count = 0
@@ -96,6 +94,6 @@ def main():
     btn = Tk.Button(root, text = "Process selected data", command = process)
     btn.grid(column = 0, row = 1)
 
-    Tk.mainloop()
+    root.mainloop()
 
 main()
\ No newline at end of file
