@@ -478,7 +478,7 @@ def retrieve_data_from_file():
 
         settings['abs_cal_type'] = 'ph/m2/sr/s/nm'
 
-        dict['efficiency calibration'] = eff
+        dict['efficiency calibration'] = np.mean(eff[None,:,:]*spectra/exp_time)
     else:
         spectra_cal = np.array(np.empty( shape=(0, 0) ))
         settings['abs_cal_type'] = 'Counts'
@@ -546,7 +546,7 @@ def load_new_data():
 
     #changes current directory to the directory where the data files are
     cur_dir = os.getcwd()
-    os.chdir('/common/projects/diagnostics/MAST/SPEXBDMS/Lightfield_output/Data_Files/')
+    os.chdir('/common/projects/diagnostics/MAST/SPEXBDMS/Lightfield_output')
     #loads the data
     dict["output"] = retrieve_data_from_file()
     o = dict["output"]
@@ -565,7 +565,13 @@ def load_new_data():
 
     A = dict["data_spectra"].tolist()
     dict["A"] = dict["data_spectra"].tolist()
+    A_min = 100*dict['efficiency calibration']
+    B_max = 50000*dict['efficiency calibration']
+    dict["horizontal"] = [["A_min",A_min], ["B_max", B_max]]
 
+    sample_rate = int(np.round(1 / ((dict["t"])[1] - (dict["t"])[0])))
+    dict["current_sample_rate"] = sample_rate
+    dict["desired_sample_rate"] = dict["current_sample_rate"]
 
     for widget in dict["subframe"].winfo_children():
         widget.destroy()
@@ -1104,51 +1110,53 @@ def run_program():
     example_spectra_wavelength = example_spectra_lines['wavelength']
 
     arr = np.stack((description, example_spectra_wavelength), axis=1)
+    dict["known_spectra_lines"] = arr
     #print(arr)
     # Stores the data into the A variable to be drawn from later
     #changes current directory to the directory where the data files are
-    cur_dir = os.getcwd()
-    os.chdir('/common/projects/diagnostics/MAST/SPEXBDMS/Lightfield_output/Data_Files/')
-    #loads the data
-    # loads the data
-    dict["output"] = retrieve_data_from_file()
-    o = dict["output"]
-    dict["o"] = dict["output"]
-    dict["wavelength_r"] = dict["output"]['wavelength']
-    dict["t"] = dict["output"]['time']
-    dict["settings"] = dict["output"]['settings']
+    if True == False:
+        cur_dir = os.getcwd()
+        os.chdir('/common/projects/diagnostics/MAST/SPEXBDMS/Lightfield_output')
+        #loads the data
+        # loads the data
+        dict["output"] = retrieve_data_from_file()
+        o = dict["output"]
+        dict["o"] = dict["output"]
+        dict["wavelength_r"] = dict["output"]['wavelength']
+        dict["t"] = dict["output"]['time']
+        dict["settings"] = dict["output"]['settings']
 
-    #if a.size == 0:
-    if len(dict["output"]['spectra_abs'])>0:
-        dict["data_spectra"] = dict["output"]['spectra_abs']
-    else:
-        dict["data_spectra"] = dict["output"]['spectra_counts']
-    #changes the directory back
-    os.chdir(cur_dir)
+        #if a.size == 0:
+        if len(dict["output"]['spectra_abs'])>0:
+            dict["data_spectra"] = dict["output"]['spectra_abs']
+        else:
+            dict["data_spectra"] = dict["output"]['spectra_counts']
+        #changes the directory back
+        os.chdir(cur_dir)
 
-    #data needs to be in the shape of - Fibre, Time, Pixel
-    dict["data_spectra"] = np.einsum('kli->lki', dict["data_spectra"]) #Converts from Time, Fibre, Pixel to Fibre, Time, Pixel.
-    dict["reference"] = dict["data_spectra"]
-    A = dict["data_spectra"].tolist()
-    dict["A"] = dict["data_spectra"].tolist()
-    sample_rate = int(np.round(1 / ((dict["t"])[1] - (dict["t"])[0])))
-    dict["current_sample_rate"] = sample_rate
-    dict["desired_sample_rate"] = dict["current_sample_rate"]
-    A_min = 0.1 * 10 ** 19
-    B_max = 1 * 10 ** 19
-    dict["horizontal"] = [["A_min",A_min], ["B_max", B_max]]
-    dict["known_spectra_lines"] = arr
+        #data needs to be in the shape of - Fibre, Time, Pixel
+        dict["data_spectra"] = np.einsum('kli->lki', dict["data_spectra"]) #Converts from Time, Fibre, Pixel to Fibre, Time, Pixel.
+        dict["reference"] = dict["data_spectra"]
+        A = dict["data_spectra"].tolist()
+        dict["A"] = dict["data_spectra"].tolist()
+        sample_rate = int(np.round(1 / ((dict["t"])[1] - (dict["t"])[0])))
+        dict["current_sample_rate"] = sample_rate
+        dict["desired_sample_rate"] = dict["current_sample_rate"]
+        A_min = 100*dict['efficiency calibration']
+        B_max = 50000*dict['efficiency calibration']
+        dict["horizontal"] = [["A_min",A_min], ["B_max", B_max]]
+        dict["known_spectra_lines"] = arr
 
     # makes the main window called dict["root"]
     dict["root"] = Tk.Tk()
     dict["root"].wm_title("GUI for data viewing")
-
+    dict["root"].geometry("1500x750")
     # creating a frame to contain the graph
 
-    dict["subframe"] = Tk.LabelFrame(dict["root"], padx=74, pady=99)
+    dict["subframe"] = Tk.LabelFrame(dict["root"], padx=100, pady=99)
     dict["subframe"].grid(row=0, column=3, padx=0, pady=0, rowspan=10, columnspan = 6)
 
-    dict["fig"] = plt.Figure()
+    dict["fig"] = plt.Figure(figsize = (10,5))
 
     btn_1 = Tk.Button(dict["root"], text="Change sample rate", command=open_sample_rate_window).grid(row=0, column=0)
 
@@ -1177,8 +1185,50 @@ def run_program():
     Tk.Radiobutton(dict["root"], text="York", variable=dict["choice"], value=1).grid(row=6, column=0, sticky=Tk.NW)
     Tk.Radiobutton(dict["root"], text="SPEX-B", variable=dict["choice"], value=2).grid(row=6, column=0, sticky=Tk.W)
 
+    if True == True:
+        dict["are_zoomed"] = False
 
-    plot_graph()
+        # esentially does what plt.show() does but in tkninter
+        canvas = FigureCanvasTkAgg(dict["fig"], dict["subframe"])
+        canvas.get_tk_widget().grid(row=1, column=2)
+
+        dict["ax"] = dict["fig"].add_subplot(111)
+        dict["fig"].subplots_adjust(bottom=0.25)
+        fibre_min = 1
+        fibre_max = 2
+        reference_time = [0,1]
+        reference_time = reference_time
+        dict["shift_multiplier"] = reference_time[1] - reference_time[0]
+        time_min = reference_time[0]
+        time_max = reference_time[-1]
+        dict["shift_offset"] = time_min
+
+        dict["ax"].axis([0, 9, 20, 40])
+        # creting all the sliders
+        dict["ax_time"] = dict["fig"].add_axes([0.12, 0.05, 0.78, 0.03])
+        dict["s_time"] = Slider(dict["ax_time"], 'Time', time_min, time_max, valinit=0, facecolor='#cc7000',
+                                valstep=dict["shift_multiplier"])
+        dict["ax_fibre"] = dict["fig"].add_axes([0.12, 0.1, 0.78, 0.03])
+        dict["s_fibre"] = Slider(dict["ax_fibre"], 'Fibre', fibre_min, fibre_max, valinit=0, valfmt=' %1.f ',
+                                 facecolor='#cc7000')
+
+        infinite = [-1 * 10 ** 100, 1 * 10 ** 100]
+
+        dict["horizontal_index"] = []
+        colour_index = ["b", "r"]
+
+
+        dict["spectra_index"] = []
+        dict["text_index"] = []
+        graph_text_index = []
+
+
+        dict["f_d"], = dict["ax"].plot([], [], linewidth=2.5, color="limegreen", picker=True)
+
+
+        dict["s_time"].on_changed(update_slider)
+        dict["s_fibre"].on_changed(update_slider)
+    #plot_graph()
 
 
     # don't remove unless you like errors in your code
